'use strict';

const React = require('react');
const Section = require('./section');
const { hamburgerIcon } = require('../nav-icons');

class MiddlePanel extends React.PureComponent {
  constructor(props) {
    super(props);

    this.state = {
      isMobile: this.props.isMobile,
      activeSection: this.props.activeSection || -1
    };

    this.renderSection = this.renderSection.bind(this);
  }

  componentWillReceiveProps(newProps) {
    this.setState({
      activeSection: newProps.activeSection,
      isMobile: newProps.isMobile
    });
  }

  onTabSelect(i, e) {
    e.preventDefault();

    if (this.state.activeSection === i) {
      i = -1;
    }

    this.props.setActiveSection(i);
    this.setState({ activeSection: i });

    return false;
  }

  renderSection(section, i) {
    let cn = 'nav-panel-middle__li nav-panel-middle__btn';

    if (this.state.activeSection === i) {
      cn += ' nav-panel-middle__li--active';
    }

    return React.createElement(Section, {
      key: i,
      href: section.href,
      isLink: section.isLink,
      text: section.text,
      extraText: section.extraText,
      className: cn,
      handler: this.onTabSelect.bind(this, i) });
  }

  render() {
    return React.createElement(
      'div',
      { className: 'nav-panel-middle' },
      React.createElement(
        'ul',
        {
          className: 'nav-panel-middle__ul flex flex--space-between flex--wrap' },
        React.createElement(
          'a',
          { href: this.props.logoLink || '/', className: 'flex flex--center-y' },
          React.createElement(
            'li',
            { className: 'nav-panel-middle__li nav-panel-middle__logo' },
            React.createElement('img', {
              className: 'nav-panel-middle__logo-img',
              src: this.props.logoUrl })
          ),
          React.createElement(
            'li',
            { className: 'nav-panel-middle__li nav-panel-middle__tagline-container' },
            React.createElement(
              'p',
              { className: 'nav-panel-middle__tagline' },
              this.props.tagline || 'For Giant Ideas'
            )
          )
        ),
        React.createElement(
          'div',
          {
            className: 'nav-panel-middle__container flex flex--center-all flex--wrap',
            style: this.state.isMobile ? { display: 'none' } : null },
          this.props.sections.map(this.renderSection)
        ),
        React.createElement(
          'li',
          {
            onClick: this.props.toggle,
            className: 'nav-panel-middle__hamburger' },
          React.createElement(
            'button',
            null,
            hamburgerIcon
          )
        )
      )
    );
  }
}

module.exports = MiddlePanel;