const React = require('react')
const Section = require('./section')
const { hamburgerIcon } = require('../nav-icons')

class MiddlePanel extends React.PureComponent {
  constructor (props) {
    super(props)

    this.state = {
      isMobile: this.props.isMobile,
      activeSection: this.props.activeSection || -1
    }

    this.renderSection = this.renderSection.bind(this)
  }

  componentWillReceiveProps (newProps) {
    this.setState({
      activeSection: newProps.activeSection,
      isMobile: newProps.isMobile
    })
  }

  onTabSelect (i, e) {
    e.preventDefault()

    if (this.state.activeSection === i) {
      i = -1
    }

    this.props.setActiveSection(i)
    this.setState({ activeSection: i })

    return false
  }

  renderSection (section, i) {
    let cn = 'nav-panel-middle__li nav-panel-middle__btn'

    if (this.state.activeSection === i) {
      cn += ' nav-panel-middle__li--active'
    }

    return <Section
      key={i}
      href={section.href}
      isLink={section.isLink}
      text={section.text}
      extraText={section.extraText}
      className={cn}
      handler={this.onTabSelect.bind(this, i)} />
  }

  render () {
    return <div className='nav-panel-middle'>
      <ul
        className='nav-panel-middle__ul flex flex--space-between flex--wrap'>
        <a href={this.props.logoLink || '/'} className='flex flex--center-y'>
          <li className='nav-panel-middle__li nav-panel-middle__logo'>
            <img
              className='nav-panel-middle__logo-img'
              src={this.props.logoUrl} />
          </li>
          <li className='nav-panel-middle__li nav-panel-middle__tagline-container'>
            <p className='nav-panel-middle__tagline'>
              { this.props.tagline || 'For Giant Ideas' }
            </p>
          </li>
        </a>
        <div
          className='nav-panel-middle__container flex flex--center-all flex--wrap'
          style={this.state.isMobile ? { display: 'none' } : null}>
          {this.props.sections.map(this.renderSection)}
        </div>
        <li
          onClick={this.props.toggle}
          className='nav-panel-middle__hamburger'>
          <button>{hamburgerIcon}</button>
        </li>
      </ul>
    </div>
  }
}

module.exports = MiddlePanel
