module.exports = TopPanel

const React = require('react')
const SearchInput = require('./search')
const {contactIcon, downloadIcon, rocketIcon} = require('../nav-icons')

function TopPanel (props) {
  const includeSearch = props.includeSearch === undefined ? true : props.includeSearch
  const downloadUrl = props.downloadUrl || '/download-center'
  const downloadJmpValue = props.downloadJmpValue || 'nav'
  const downloadJmp = downloadJmpValue === '' ? '' : `?jmp=${downloadJmpValue}`

  return <div className='nav-panel-top font--center'>
    <ul className='flex flex--space-between' style={{ height: '100%' }}>
      <div className='nav-panel-top__links flex flex--center-y font--center'>
        {props.sections.map(renderSection)}
      </div>

      <div className='flex flex--center-y'>
        <a href={props.contactUrl || '/contact?jmp=nav'}>
          <button
            className='flex flex--center-all flex--wrap nav-panel-top__contact'
            style={!includeSearch ? { marginRight: '15px' } : null}>
            {contactIcon}
          </button>
        </a>

        {includeSearch &&
        <SearchInput searchUrl={props.searchUrl || '/search?search='} />}

        <a
          id='mongodb-nav-hosting-btn'
          className='nav-panel-top__a'
          href='/cloud/atlas?jmp=nav'>
          <button className='btn-small btn-hollow btn-hollow--light-green margin--left-xs nav-panel-top__hosting'>
            <span style={{ verticalAlign: 'middle' }}>Free Sandbox</span>
            {rocketIcon}
          </button>
        </a>

        <a
          id='mongodb-nav-download-btn'
          className='nav-panel-top__a'
          href={`${props.host}${downloadUrl}${downloadJmp}`}
          target={props.host === '' ? '_self' : '_blank'}>
          <button className='btn-small btn-fill btn-fill--light-green margin--left-xs nav-panel-top__download'>
            <span style={{ verticalAlign: 'middle' }}>Download</span>
            {downloadIcon}
          </button>
        </a>
      </div>
    </ul>
  </div>
}

function renderSection (section, i) {
  return <a
    key={i}
    className='nav-panel-top__a'
    target={section.self ? '_self' : '_blank'}
    href={section.href}>
    <li className='nav-panel-top__li'>{section.text}</li>
  </a>
}
